
## EROS-core

Build test

[![Python test package installation](https://github.com/Florioo/eros-core-python/actions/workflows/test_installation.yml/badge.svg)](https://github.com/Florioo/eros-core-python/actions/workflows/test_installation.yml)
